piecash.business.person module — Python interface to GnuCash documents 0.14.1 documentation

# piecash.business.person module

class `piecash.business.person.` `Address`(name='', addr1='', addr2='', addr3='', addr4='', email='', fax='', phone='')

  Bases: `object`

  An Address object encapsulates information regarding an address in GnuCash.

  `name`

    str – self explanatory

  `addr1`

    str – self explanatory

  `addr2`

    str – self explanatory

  `addr3`

    str – self explanatory

  `addr4`

    str – self explanatory

  `email`

    str – self explanatory

  `fax`

    str – self explanatory

  `phone`

    str – self explanatory

class `piecash.business.person.` `Customer`(name, currency, id=None, notes='', active=1, tax_override=0, credit=Decimal('0'), discount=Decimal('0'), taxtable=None, address=None, shipping_address=None, tax_included='USEGLOBAL', book=None)

  Bases: `piecash._declbase.DeclarativeBaseGuid`

  A GnuCash Customer

  `name`

    str – name of the Customer

  `id`

    str – autonumber id with 5 digits (initialised to book.counter_customer + 1)

  `notes`

    str – notes

  `active`

    int – 1 if the customer is active, 0 otherwise

  `discount`

    `decimal.Decimal` – see Gnucash documentation

  `credit`

    `decimal.Decimal` – see Gnucash documentation

  `currency`

    `piecash.core.commodity.Commodity` – the currency of the customer

  `tax_override`

    int – 1 if tax override, 0 otherwise

  `address`

    `Address` – the address of the customer

  `shipping_address`

    `Address` – the shipping address of the customer

  `tax_included`

    str – ‘yes’, ‘no’, ‘use global’

  `taxtable`

    `piecash.business.tax.TaxTable` – tax table of the customer

  `term`

    `piecash.business.invoice.Billterm` – bill term of the customer

class `piecash.business.person.` `Employee`(name, currency, creditcard_account=None, id=None, active=1, acl='', language='', workday=Decimal('0'), rate=Decimal('0'), address=None, book=None)

  Bases: `piecash._declbase.DeclarativeBaseGuid`

  A GnuCash Employee

  `name`

    str – name of the Employee

  `id`

    str – autonumber id with 5 digits (initialised to book.counter_employee + 1)

  `language`

    str – language

  `active`

    int – 1 if the employee is active, 0 otherwise

  `workday`

    `decimal.Decimal` – see Gnucash documentation

  `rate`

    `decimal.Decimal` – see Gnucash documentation

  `currency`

    `piecash.core.commodity.Commodity` – the currency of the employee

  `address`

    `Address` – the address of the employee

  `creditcard_account`

    `piecash.core.account.Account` – credit card account for the employee

class `piecash.business.person.` `Vendor`(name, currency, id=None, notes='', active=1, tax_override=0, taxtable=None, credit=Decimal('0'), discount=Decimal('0'), address=None, tax_included='USEGLOBAL', book=None)

  Bases: `piecash._declbase.DeclarativeBaseGuid`

  A GnuCash Vendor

  `name`

    str – name of the Vendor

  `id`

    str – autonumber id with 5 digits (initialised to book.counter_vendor + 1)

  `notes`

    str – notes

  `active`

    int – 1 if the vendor is active, 0 otherwise

  `currency`

    `piecash.core.commodity.Commodity` – the currency of the vendor

  `tax_override`

    int – 1 if tax override, 0 otherwise

  `address`

    `Address` – the address of the vendor

  `tax_included`

    str – ‘YES’, ‘NO’, ‘USEGLOBAL’

  `taxtable`

    `piecash.business.tax.TaxTable` – tax table of the vendor

  `term`

    `piecash.business.invoice.Billterm` – bill term of the vendor